@@ -19,6 +19,7 @@
 The Desired Capabilities implementation.
 """
 
+
 class DesiredCapabilities(object):
     """
     Set of default supported desired capabilities.
@@ -62,6 +63,12 @@ class DesiredCapabilities(object):
         "javascriptEnabled": True,
     }
 
+    EDGE = {
+        "browserName": "MicrosoftEdge",
+        "version": "",
+        "platform": "WINDOWS"
+    }
+
     CHROME = {
         "browserName": "chrome",
         "version": "",
@@ -79,7 +86,7 @@ class DesiredCapabilities(object):
     SAFARI = {
         "browserName": "safari",
         "version": "",
-        "platform": "ANY",
+        "platform": "MAC",
         "javascriptEnabled": True,
     }
 
@@ -118,7 +125,7 @@ class DesiredCapabilities(object):
     }
 
     PHANTOMJS = {
-        "browserName":"phantomjs",
+        "browserName": "phantomjs",
         "version": "",
         "platform": "ANY",
         "javascriptEnabled": True,
