@@ -1,5 +1,3 @@
-#!/usr/bin/python
-#
 # Licensed to the Software Freedom Conservancy (SFC) under one
 # or more contributor license agreements.  See the NOTICE file
 # distributed with this work for additional information
@@ -16,6 +14,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+
 from __future__ import with_statement
 
 import base64
@@ -82,7 +81,7 @@ class FirefoxProfile(object):
         self.extensionsDir = os.path.join(self.profile_dir, "extensions")
         self.userPrefs = os.path.join(self.profile_dir, "user.js")
 
-    #Public Methods
+    # Public Methods
     def set_preference(self, key, value):
         """
         sets the preference that we want in the profile.
@@ -97,7 +96,7 @@ class FirefoxProfile(object):
             self.default_preferences[key] = value
         self._write_user_prefs(self.default_preferences)
 
-    #Properties
+    # Properties
 
     @property
     def path(self):
@@ -124,7 +123,7 @@ class FirefoxProfile(object):
             port = int(port)
             if port < 1 or port > 65535:
                 raise WebDriverException("Port number must be in the range 1..65535")
-        except (ValueError, TypeError) as e:
+        except (ValueError, TypeError):
             raise WebDriverException("Port needs to be an integer")
         self._port = port
         self.set_preference("webdriver_firefox_port", self._port)
@@ -166,6 +165,7 @@ class FirefoxProfile(object):
         A zipped, base64 encoded string of profile directory
         for use with remote WebDriver JSON wire protocol
         """
+        self.update_preferences()
         fp = BytesIO()
         zipped = zipfile.ZipFile(fp, 'w', zipfile.ZIP_DEFLATED)
         path_root = len(self.path) + 1  # account for trailing slash
@@ -255,8 +255,9 @@ class FirefoxProfile(object):
             tmpdir = tempfile.mkdtemp(suffix='.' + os.path.split(addon)[-1])
             compressed_file = zipfile.ZipFile(addon, 'r')
             for name in compressed_file.namelist():
-                if name.endswith('/') and not os.path.isdir(os.path.join(tmpdir, name)):
-                    os.makedirs(os.path.join(tmpdir, name))
+                if name.endswith('/'):
+                    if not os.path.isdir(os.path.join(tmpdir, name)):
+                        os.makedirs(os.path.join(tmpdir, name))
                 else:
                     if not os.path.isdir(os.path.dirname(os.path.join(tmpdir, name))):
                         os.makedirs(os.path.dirname(os.path.join(tmpdir, name)))
