@@ -54,8 +54,8 @@ class WebDriver(object):
     """
 
     def __init__(self, command_executor='http://127.0.0.1:4444/wd/hub',
-            desired_capabilities=None, browser_profile=None, proxy=None, keep_alive=False,
-            file_detector=None):
+                 desired_capabilities=None, browser_profile=None, proxy=None,
+                 keep_alive=False, file_detector=None):
         """
         Create a new driver that will issue commands using the wire protocol.
 
@@ -166,12 +166,12 @@ class WebDriver(object):
          - javascript_enabled - Whether the new session should support JavaScript.
          - browser_profile - A selenium.webdriver.firefox.firefox_profile.FirefoxProfile object. Only used if Firefox is requested.
         """
-        capabilities = {'desiredCapabilities': {}}
+        capabilities = {'desiredCapabilities': {}, 'requiredCapabilities': {}}
         for k, v in desired_capabilities.items():
             if k not in ('desiredCapabilities', 'requiredCapabilities'):
                 capabilities['desiredCapabilities'][k] = v
             else:
-                capabilities[k] = v
+                capabilities[k].update(v)
         if browser_profile:
             capabilities['desiredCapabilities']['firefox_profile'] = browser_profile.encoded
         response = self.execute(Command.NEW_SESSION, capabilities)
@@ -460,8 +460,9 @@ class WebDriver(object):
             driver.execute_script('document.title')
         """
         converted_args = list(args)
-        return self.execute(Command.EXECUTE_SCRIPT,
-            {'script': script, 'args':converted_args})['value']
+        return self.execute(Command.EXECUTE_SCRIPT, {
+            'script': script,
+            'args': converted_args})['value']
 
     def execute_async_script(self, script, *args):
         """
@@ -475,8 +476,9 @@ class WebDriver(object):
             driver.execute_async_script('document.title')
         """
         converted_args = list(args)
-        return self.execute(Command.EXECUTE_ASYNC_SCRIPT,
-            {'script': script, 'args':converted_args})['value']
+        return self.execute(Command.EXECUTE_ASYNC_SCRIPT, {
+            'script': script,
+            'args': converted_args})['value']
 
     @property
     def current_url(self):
@@ -552,7 +554,7 @@ class WebDriver(object):
     def switch_to(self):
         return self._switch_to
 
-    #Target Locators
+    # Target Locators
     def switch_to_active_element(self):
         """ Deprecated use driver.switch_to.active_element
         """
@@ -583,7 +585,7 @@ class WebDriver(object):
         warnings.warn("use driver.switch_to.alert instead", DeprecationWarning)
         return self._switch_to.alert
 
-    #Navigation
+    # Navigation
     def back(self):
         """
         Goes one step backward in the browser history.
@@ -683,10 +685,12 @@ class WebDriver(object):
             driver.implicitly_wait(30)
         """
         if self.w3c:
-            self.execute(Command.SET_TIMEOUTS,
-                         {'ms': float(time_to_wait) * 1000, 'type':'implicit'})
+            self.execute(Command.SET_TIMEOUTS, {
+                'ms': float(time_to_wait) * 1000,
+                'type': 'implicit'})
         else:
-            self.execute(Command.IMPLICIT_WAIT, {'ms': float(time_to_wait) * 1000})
+            self.execute(Command.IMPLICIT_WAIT, {
+                'ms': float(time_to_wait) * 1000})
 
     def set_script_timeout(self, time_to_wait):
         """
@@ -700,11 +704,12 @@ class WebDriver(object):
             driver.set_script_timeout(30)
         """
         if self.w3c:
-            self.execute(Command.SET_TIMEOUTS,
-                         {'ms': float(time_to_wait) * 1000, 'type':'script'})
+            self.execute(Command.SET_TIMEOUTS, {
+                'ms': float(time_to_wait) * 1000,
+                'type': 'script'})
         else:
-            self.execute(Command.SET_SCRIPT_TIMEOUT,
-                         {'ms': float(time_to_wait) * 1000})
+            self.execute(Command.SET_SCRIPT_TIMEOUT, {
+                'ms': float(time_to_wait) * 1000})
 
     def set_page_load_timeout(self, time_to_wait):
         """
@@ -717,8 +722,9 @@ class WebDriver(object):
         :Usage:
             driver.set_page_load_timeout(30)
         """
-        self.execute(Command.SET_TIMEOUTS,
-            {'ms': float(time_to_wait) * 1000, 'type':'page load'})
+        self.execute(Command.SET_TIMEOUTS, {
+            'ms': float(time_to_wait) * 1000,
+            'type': 'page load'})
 
     def find_element(self, by=By.ID, value=None):
         """
@@ -741,8 +747,9 @@ class WebDriver(object):
             elif by == By.NAME:
                 by = By.CSS_SELECTOR
                 value = '[name="%s"]' % value
-        return self.execute(Command.FIND_ELEMENT,
-                             {'using': by, 'value': value})['value']
+        return self.execute(Command.FIND_ELEMENT, {
+            'using': by,
+            'value': value})['value']
 
     def find_elements(self, by=By.ID, value=None):
         """
@@ -766,8 +773,10 @@ class WebDriver(object):
                 by = By.CSS_SELECTOR
                 value = '[name="%s"]' % value
 
-        return self.execute(Command.FIND_ELEMENTS,
-                             {'using': by, 'value': value})['value']
+        return self.execute(Command.FIND_ELEMENTS, {
+            'using': by,
+            'value': value})['value']
+
     @property
     def desired_capabilities(self):
         """
@@ -831,8 +840,10 @@ class WebDriver(object):
         command = Command.SET_WINDOW_SIZE
         if self.w3c:
             command = Command.W3C_SET_WINDOW_SIZE
-        self.execute(command, {'width': int(width), 'height': int(height),
-          'windowHandle': windowHandle})
+        self.execute(command, {
+            'width': int(width),
+            'height': int(height),
+            'windowHandle': windowHandle})
 
     def get_window_size(self, windowHandle='current'):
         """
@@ -844,10 +855,9 @@ class WebDriver(object):
         command = Command.GET_WINDOW_SIZE
         if self.w3c:
             command = Command.W3C_GET_WINDOW_SIZE
-        size = self.execute(command,
-            {'windowHandle': windowHandle})
+        size = self.execute(command, {'windowHandle': windowHandle})
 
-        if size.get('value', None) != None:
+        if size.get('value', None) is not None:
             return size['value']
         else:
             return size
@@ -863,8 +873,10 @@ class WebDriver(object):
         :Usage:
             driver.set_window_position(0,0)
         """
-        self.execute(Command.SET_WINDOW_POSITION, {'x': int(x), 'y': int(y),
-          'windowHandle': windowHandle})
+        self.execute(Command.SET_WINDOW_POSITION, {
+            'x': int(x),
+            'y': int(y),
+            'windowHandle': windowHandle})
 
     def get_window_position(self, windowHandle='current'):
         """
@@ -873,8 +885,8 @@ class WebDriver(object):
         :Usage:
             driver.get_window_position()
         """
-        return self.execute(Command.GET_WINDOW_POSITION,
-            {'windowHandle': windowHandle})['value']
+        return self.execute(Command.GET_WINDOW_POSITION, {
+            'windowHandle': windowHandle})['value']
 
     @property
     def file_detector(self):
@@ -893,11 +905,11 @@ class WebDriver(object):
         :Args:
          - detector: The detector to use. Must not be None.
         """
-        if detector == None:
+        if detector is None:
             raise WebDriverException("You may not set a file detector that is null")
         if not isinstance(detector, FileDetector):
             raise WebDriverException("Detector has to be instance of FileDetector")
-        self._file_detector = detector;
+        self._file_detector = detector
 
     @property
     def orientation(self):
