@@ -16,7 +16,6 @@
 # under the License.
 
 import hashlib
-from numbers import Number
 import os
 import zipfile
 try:
@@ -27,9 +26,8 @@ import base64
 
 from .command import Command
 from selenium.common.exceptions import WebDriverException
-from selenium.common.exceptions import InvalidSelectorException
 from selenium.webdriver.common.by import By
-from selenium.webdriver.common.keys import Keys
+from selenium.webdriver.common.utils import keys_to_typing
 
 
 try:
@@ -59,7 +57,6 @@ class WebElement(object):
         return '<{0.__module__}.{0.__name__} (session="{1}", element="{2}")>'.format(
             type(self), self._parent.session_id, self._id)
 
-
     @property
     def tag_name(self):
         """This element's ``tagName`` property."""
@@ -78,9 +75,10 @@ class WebElement(object):
         """Submits a form."""
         if self._w3c:
             form = self.find_element(By.XPATH, "./ancestor-or-self::form")
-            self._parent.execute_script("var e = arguments[0].ownerDocument.createEvent('Event');"
-                                       "e.initEvent('submit', true, true);"
-                                       "if (arguments[0].dispatchEvent(e)) { arguments[0].submit() }", form)
+            self._parent.execute_script(
+                "var e = arguments[0].ownerDocument.createEvent('Event');"
+                "e.initEvent('submit', true, true);"
+                "if (arguments[0].dispatchEvent(e)) { arguments[0].submit() }", form)
         else:
             self._execute(Command.SUBMIT_ELEMENT)
 
@@ -265,7 +263,6 @@ class WebElement(object):
         """
         return self.find_element(by=By.CLASS_NAME, value=name)
 
-
     def find_elements_by_class_name(self, name):
         """Finds a list of elements within this element's children by class name.
 
@@ -320,18 +317,7 @@ class WebElement(object):
             if local_file is not None:
                 value = self._upload(local_file)
 
-        typing = []
-        for val in value:
-            if isinstance(val, Keys):
-                typing.append(val)
-            elif isinstance(val, Number):
-                val = val.__str__()
-                for i in range(len(val)):
-                    typing.append(val[i])
-            else:
-                for i in range(len(val)):
-                    typing.append(val[i])
-        self._execute(Command.SEND_KEYS_TO_ELEMENT, {'value': typing})
+        self._execute(Command.SEND_KEYS_TO_ELEMENT, {'value': keys_to_typing(value)})
 
     # RenderedWebElement Items
     def is_displayed(self):
@@ -348,7 +334,14 @@ class WebElement(object):
         the element is not visible.
 
         """
-        return self._execute(Command.GET_ELEMENT_LOCATION_ONCE_SCROLLED_INTO_VIEW)['value']
+        if self._w3c:
+            old_loc = self._execute(Command.EXECUTE_SCRIPT, {
+                'script': "arguments[0].scrollIntoView(true); return arguments[0].getBoundingClientRect()",
+                'args': [self]})['value']
+            return {"x": round(old_loc['x']),
+                    "y": round(old_loc['y'])}
+        else:
+            return self._execute(Command.GET_ELEMENT_LOCATION_ONCE_SCROLLED_INTO_VIEW)['value']
 
     @property
     def size(self):
@@ -364,8 +357,8 @@ class WebElement(object):
 
     def value_of_css_property(self, property_name):
         """The value of a CSS property."""
-        return self._execute(Command.GET_ELEMENT_VALUE_OF_CSS_PROPERTY,
-                        {'propertyName': property_name})['value']
+        return self._execute(Command.GET_ELEMENT_VALUE_OF_CSS_PROPERTY, {
+            'propertyName': property_name})['value']
 
     @property
     def location(self):
@@ -374,8 +367,8 @@ class WebElement(object):
             old_loc = self._execute(Command.GET_ELEMENT_RECT)
         else:
             old_loc = self._execute(Command.GET_ELEMENT_LOCATION)['value']
-        new_loc = {"x": old_loc['x'],
-                   "y": old_loc['y']}
+        new_loc = {"x": round(old_loc['x']),
+                   "y": round(old_loc['y'])}
         return new_loc
 
     @property
@@ -427,7 +420,6 @@ class WebElement(object):
             del png
         return True
 
-
     @property
     def parent(self):
         """Internal reference to the WebDriver instance this element was found from."""
@@ -469,9 +461,6 @@ class WebElement(object):
         return self._parent.execute(command, params)
 
     def find_element(self, by=By.ID, value=None):
-        if not By.is_valid(by) or not isinstance(value, str):
-            raise InvalidSelectorException("Invalid locator values passed in")
-
         if self._w3c:
             if by == By.ID:
                 by = By.CSS_SELECTOR
@@ -489,9 +478,6 @@ class WebElement(object):
                              {"using": by, "value": value})['value']
 
     def find_elements(self, by=By.ID, value=None):
-        if not By.is_valid(by) or not isinstance(value, str):
-            raise InvalidSelectorException("Invalid locator values passed in")
-
         if self._w3c:
             if by == By.ID:
                 by = By.CSS_SELECTOR
@@ -520,8 +506,7 @@ class WebElement(object):
         if not isinstance(content, str):
             content = content.decode('utf-8')
         try:
-            return self._execute(Command.UPLOAD_FILE,
-                            {'file': content})['value']
+            return self._execute(Command.UPLOAD_FILE, {'file': content})['value']
         except WebDriverException as e:
             if "Unrecognized command: POST" in e.__str__():
                 return filename
